Cbuf

Struct Cbuf 

pub struct Cbuf { /* private fields */ }
A thread-safe, lock-protected circular byte buffer.

Implementations

Source

impl Cbuf

pub fn project<'__pin>(self: Pin<&'__pin mut Self>) -> CbufProjection<'__pin>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • event
  • lock

These fields are not structurally pinned:

  • head
  • tail
  • len_pow2
  • buf
Source

impl Cbuf

pub fn lock_lock(&self) -> impl PinInit<CbufLockGuard<'_>, Infallible>

Source

impl Cbuf

pub fn init() -> impl PinInit<Self, Infallible>

Returns a pin initializer for a new, uninitialized Cbuf.

pub unsafe fn initialize(&self, len: usize, buf: *mut u8) -> Result<(), Status>

Initializes the circular buffer with the specified size and backing memory region.

Safety

The caller must ensure that buf points to a valid memory region of at least len bytes, and that this memory region remains valid for the lifetime of Cbuf.

pub fn full(&self) -> bool

Returns true if the buffer is currently full.

pub fn write_char(&self, c: u8) -> usize

Writes a single character to the buffer if space is available.

Returns 1 if the write succeeded, or 0 if the buffer was full.

pub fn read_char_with_context(&self, block: bool) -> Result<ReadContext, Status>

Reads a single character from the buffer, returning it along with the transition context.

If block is true, this function blocks until a character is available to read. If block is false, it returns Err(Status::SHOULD_WAIT) if no character is available.

pub fn read_char(&self, block: bool) -> Result<u8, Status>

Reads a single character from the buffer.

If block is true, this function blocks until a character is available to read. If block is false, it returns Err(Status::SHOULD_WAIT) if no character is available.