pub struct ReadContext {
pub c: u8,
pub transitioned_from_full: bool,
}Expand description
Context returned along with a character read from the circular buffer.
Fields
c: u8The character that was read.
transitioned_from_full: boolWhether the buffer transitioned away from being completely full as a result of this read.